require 'spec_helper'

describe Rack::SL do

  context '.call' do
    let(:app) { lambda { |env| env }}
    let(:middleware) do
      Rack::SL.new(app)
    end

    context 'with no SL headers' do
      let(:request_env) { default_env }
      let(:env) { middleware.call(request_env) }

      it 'should add SL information to env' do
        env.should include('sl')
      end

      it 'should identify that the request is not from SL' do
        env['sl'].from_sl.should eq(false)
      end
    end

    context 'with valid SL headers' do
      let(:request_env) { valid_headers }
      let(:env) { middleware.call(request_env) }
      let(:sl) { env['sl'] }

      it 'should add SL information to env' do
        env.should include('sl')
      end

      it 'should identify that the request is from SL' do
        sl.from_sl.should eq(true)
      end

      it 'should parse header information' do
        sl.region.name.should eq('Jin Ho')
        sl.region.x.should eq(264448)
        sl.region.y.should eq(233984)
        sl.name.should eq('Object')
        sl.key.should eq('01234567-89ab-cdef-0123-456789abcdef')
        sl.owner.name.should eq('Nivardus String')
        sl.owner.key.should eq('01234567-89ab-cdef-0123-456789abcdef')
        sl.position.x.should eq(173.009827)
        sl.position.y.should eq(75.551231)
        sl.position.z.should eq(60.950001)
        sl.rotation.x.should eq(-0.17304)
        sl.rotation.y.should eq(0.14914)
        sl.rotation.z.should eq(0.22335)
        sl.rotation.s.should eq(0.94759)
        sl.velocity.x.should eq(1.0)
        sl.velocity.y.should eq(0.5)
        sl.velocity.z.should eq(-0.25)
      end
    end

    context 'with invalid SL headers' do
      let(:request_env) { invalid_headers }
      let(:env) { middleware.call(request_env) }

      it 'should add SL information to env' do
        env.should include('sl')
      end

      it 'should identify that the request is not from SL' do
        env['sl'].from_sl.should eq(false)
      end

      it 'should include the first error' do
        env['sl'].error.should_not eq(nil)
      end
    end
  end
end
